/*
* file CcMergeHandlingCallback.java
*
* Licensed Materials - Property of IBM
* Restricted Materials of IBM
* 
* com.ibm.rational.wvcm.stp.cc.CcMergeHandlingCallback
*
* (C) Copyright IBM Corporation 2008.  All Rights Reserved. 
* Note to U.S. Government Users Restricted Rights:  Use, duplication or  
* disclosure restricted by GSA ADP  Schedule Contract with IBM Corp. 
*/

package com.ibm.rational.wvcm.stp.cc;

import javax.wvcm.WvcmException;

import com.ibm.rational.wvcm.stpex.StpExEnumeration;
import com.ibm.rational.wvcm.stpex.StpExEnumerationBase;

/**
 * Interface to let the GUI deal with merge operations on checkin.
 */
public interface CcMergeHandlingCallback {
    
    /** 
     * Enumeration to specify how to deal with the checkin
     * after a merge. 
     */
    enum CheckinMergeHandling {
        
        /** Don't do anything else */
        LEAVE_CHECKED_OUT("leave-checked-out"),
        
        /** Retry the checkin */
        RETRY_CHECKIN("retry-checkin"),
        
        /** Fail remaining checkins */
        CANCEL_REMAINING_CHECKINS("cancel-remaining-checkins");
        
        private String m_name;

        private CheckinMergeHandling(String name) { m_name = name; }

        /* (non-Javadoc)
         * @see java.lang.Object#toString()
         */
        public String toString() { return m_name; }
    }
    

    /**
     * This method is called when a manual merge from LATEST is needed.
     * @param file the file we're merging
     * @param fromVersion the base version
     * @param toVersion the version we're merging with
     * @return CheckinMergeHandling enumeration specifying how the checkin 
     *         is to be handled after the merge
     */
    CheckinMergeHandling performManualMerge(
            CcFile file,
            CcVersion fromVersion,
            CcVersion toVersion) throws WvcmException;

}
